@@ -3,10 +3,10 @@ import tensorflow as tf
 import tensorflow_datasets as tfds
 import numpy as np
 import sys, os
+from py_common_util.common.annotations import print_exec_time
 from skydl.datasets.movielens_dataset_builder import MovieLensDatasetBuilder
 from skydl.model.default_model import DefaultModel
 from tensorflow import keras
-from py_common_util.common.common_utils import CommonUtils
 from skydl.model.impl.movielens_wide_deep_keras_model import MovieLensWideDeepKerasModel
 from skydl.model.impl.movielens_wide_deep_keras_model1 import MovieLensWideDeepKerasModel1
 from skydl.model.impl.movielens_wide_deep_keras_model2 import MovieLensWideDeepKerasModel2
@@ -14,12 +14,12 @@ from skydl.model.keras_feature_input_layer_merged_model import KerasFeatureInput
 sys.path.append(os.path.abspath('%s/..' % sys.path[0]))
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_default_model():
     DefaultModel().fit()
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_keras_model():
     from skydl.model.impl.my_keras_model import MyKerasModel
     # feature_columns = [tf.feature_column.numeric_column("image", shape=[28, 28])]
@@ -33,7 +33,8 @@ def run_keras_model():
         keras.optimizers.Adam(),
         ['accuracy']
         # ['accuracy', keras.metrics.Precision(), keras.metrics.Recall()]
-    ).fit().serving()
+    ).fit()
+    # .serving()
 
     inference_model = MyKerasModel()
     _, evaluate_dataset, _ = inference_model.load_data()
@@ -46,7 +47,7 @@ def run_keras_model():
     # print("the inference results:", labels.tolist()[:2])
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_wine_wide_deep_keras_model():
     from skydl.model.impl.wine_wide_deep_keras_model import WineWideDeepKerasModel
     WineWideDeepKerasModel("wine_wide_deep_keras_model", [
@@ -61,7 +62,7 @@ def run_wine_wide_deep_keras_model():
     ).fit()
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_movielens_wide_deep_keras_model_ok():
     from skydl.model.impl.movielens_wide_deep_keras_model import MovieLensWideDeepKerasModel
     MovieLensWideDeepKerasModel("movielens_wide_deep_keras_model1", [
@@ -74,7 +75,7 @@ def run_movielens_wide_deep_keras_model_ok():
     ).fit_ok()
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_movielens_wide_deep_keras_model():
     """
     1.Best Practices on Recommendation Systems https://github.com/microsoft/recommenders
@@ -156,7 +157,7 @@ def run_movielens_wide_deep_keras_model():
     merged_model.model.model_proxy.summary()
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_my_estimator_model():
     from tensorflow_estimator import estimator
     from tensorflow.python import feature_column
@@ -214,7 +215,7 @@ def run_my_estimator_model():
                     }).compile().fit()
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_my_estimator_model2():
     import pandas as pd
     from tensorflow_estimator import estimator
@@ -252,7 +253,7 @@ def run_my_estimator_model2():
                      model_fn=est.model_fn).compile().fit2()
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_keras_model_to_estimator():
     from skydl.model.impl.my_keras_model import MyKerasModel
     model = MyKerasModel("my_keras_model_to_estimator", [
@@ -274,7 +275,7 @@ def run_keras_model_to_estimator():
     print(pd.Series(result))
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_hst_recommend_system():
     """推荐系统：协同过滤"""
     from skydl.model.impl.movielens_wide_deep_keras_model import MovieLensWideDeepKerasModel
@@ -317,7 +318,7 @@ def run_hst_recommend_system():
                 features_list=[{"user_id": np_user_ids[3], "item_id": np_item_ids[i]} for i in range(len(np_item_ids[:400]))])
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_hst_recommend_system1():
     """推荐系统：协同过滤"""
     from skydl.model.impl.movielens_wide_deep_keras_model import MovieLensWideDeepKerasModel
@@ -375,7 +376,7 @@ def run_hst_recommend_system1():
     #             features_list=[{"user_id": np_user_ids[3].tolist(), "item_id": np_item_ids[i].tolist()} for i in range(len(np_item_ids[:400]))])
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def run_hst_recommend_system2():
     """推荐系统：协同过滤"""
     from skydl.model.impl.movielens_wide_deep_keras_model import MovieLensWideDeepKerasModel
@@ -415,7 +416,7 @@ def run_hst_recommend_system2():
                 features_list=[{"user_id": np_user_ids[3], "item_id": np_item_ids[i]} for i in range(len(np_item_ids[:400]))])
 
 
-@CommonUtils.print_exec_time
+@print_exec_time
 def keras_input_will_ok_no_need_delete():
     import pandas as pd
     df = pd.DataFrame(
