@@ -25,17 +25,29 @@ if __name__ == "__main__":
     args = parser.parse_args()
     titles_file = str(args.titles_file)
     ######################################
+    # import ray
+    # import time
+    # ray.init(address="auto")
+    # @ray.remote
+    # def f(i):
+    #     print("remote function....")
+    #     time.sleep(10)
+    #     return i
+    # futures = [f.remote(i) for i in range(20)]
+    # print(ray.get(futures))
+    # ray.shutdown()
     import ray
     import time
-    ray.init(address="auto")
+    ray.init()
     @ray.remote
-    def f(i):
-        print("remote function....")
-        time.sleep(1)
-        return i
-    futures = [f.remote(i) for i in range(5)]
-    print(ray.get(futures))
-    ray.shutdown()
+    def f():
+        return b""
+    n = 1000
+    f_direct = f.options(is_direct_call=True)
+    while True:
+        start = time.time()
+        ray.get([f_direct.remote() for _ in range(n)])
+        print(n / (time.time() - start), "calls per second")
     ######################################
     # ray.init(address="auto", load_code_from_local=True, include_java=True)
     # ctx = StreamingContext.Builder() \
